summaryrefslogtreecommitdiffstats
path: root/kplato/kptdatetable.h
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kptdatetable.h')
-rw-r--r--kplato/kptdatetable.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kplato/kptdatetable.h b/kplato/kptdatetable.h
index 815a86e9..9cd992e3 100644
--- a/kplato/kptdatetable.h
+++ b/kplato/kptdatetable.h
@@ -104,11 +104,11 @@ public:
/**
* The size hint.
*/
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
/**
* The minimum size hint.
*/
- TQSize tqminimumSizeHint() const { return tqsizeHint(); }
+ TQSize minimumSizeHint() const { return sizeHint(); }
/**
* Return the result. 0 means no selection (reject()), 1..12 are the
* months.
@@ -260,7 +260,7 @@ public:
/**
* The constructor.
*/
- DateTable(TQWidget *parent=0, TQDate date=TQDate::tqcurrentDate(),
+ DateTable(TQWidget *parent=0, TQDate date=TQDate::currentDate(),
const char* name="DateTable", WFlags f=0);
/**
@@ -268,9 +268,9 @@ public:
* To save some time, the size of the largest used cell content is
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
* tqsizeHint() simply returns a multiple of maxCell.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* Set the font size of the date table.
*/
@@ -268,9 +268,9 @@ public:
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
- * tqsizeHint() simply returns a multiple of maxCell.
+ * sizeHint() simply returns a multiple of maxCell.
*/